## ----using randomizations,echo=FALSE, eval=TRUE--------------------------


########### Using randomizations

rand=1000 # Set number of randomizations

#isoptera$ModuloID<-env$ModuloID[match(isoptera$PlotID,env$PlotID)] # Select on termite data only plots with environmental data

attach(isoptera)

unique.section.split<-tapply(ModuloID,PlotID,function(x)unique(isoptera[ModuloID==x[1],"Section"])) # List all sections sampled in each transect (if missing, look at other transects within grid)

section.split<-split(Section,PlotID) # List all sections where termites were found

isoptera.split<-split(isoptera,PlotID) # split termite table by transect

isoptera.unsplit<-do.call(rbind,isoptera.split) # merge termite data again; Note that the order data points changed

termite.plot.cor<-array(NA,dim=c(nlevels(env$PlotID),nlevels(isopteraTaxonID$TaxonID),rand)) # Create empty array to receive data (cor for corrected)


iso.plot.fac<-factor(isoptera.unsplit$PlotID,levels=env$PlotID) # Create factor with all transects present in environmental matrix
iso.tax.fac<-factor(isoptera.unsplit$TaxonID,levels=isopteraTaxonID$TaxonID) # Create factor with all species present in taxonomic matrix

for(i in 1:rand){
	
	select<-{} # Create empty vector
	
	for(k in 1:nlevels(PlotID)){ # Loop for each transect
		select<-c(select,section.split[[k]]%in%sample(unique.section.split[[k]],5)) # Randomly select up to 5 sections from each transect; In each transect, determine which section is or not selected
		}

	termite.plot.cor[,,i]<-tapply(select,list(iso.plot.fac,iso.tax.fac),sum) #For each comb of species and transect, sum spp occurrence from selected sections
	}

detach(isoptera)

##

termite.plot.cor[is.na(termite.plot.cor)]<-0 # Transects where species were not found are true zeros, so change NAs for zeros

###create_respvars

termite.plot.rand<-apply(termite.plot.cor,2,rowMeans)# Species average abundance per transect
termite.plot.PA.rand<-apply(termite.plot.cor>0,2,rowMeans) # Specie average occurrence per transect

termite.plot.rand[rowSums(termite.plot.rand)==0,]<-NA # If no termite was not found in transect, then consider not searched (true NA)
termite.plot.PA.rand[rowSums(termite.plot.PA.rand)==0,]<-NA # If no termite was not found in transect, then consider not searched (true NA)

colnames(termite.plot.rand)<-isopteraTaxonID$TaxonID # Put species names in table
colnames(termite.plot.PA.rand)<-isopteraTaxonID$TaxonID # The same for PA

rownames(termite.plot.rand)<-env$PlotID # Put plot names in table
rownames(termite.plot.PA.rand)<-env$PlotID # The same for PA


termite.N.rand<-rowMeans(apply(termite.plot.cor,3,rowSums)) # Calculate average species abundances per transect
termite.S.rand<-rowMeans(apply(termite.plot.cor>0,3,rowSums)) # Average species richness per transect


##

termite.N.rand[termite.N.rand==0]<-NA # If no termite was not found in transect, then consider not searched (true NA)
termite.S.rand[termite.N.rand==0]<-NA # If no termite was not found in transect, then consider not searched (true NA)


termite.N.sd.rand<-apply(apply(termite.plot.cor,3,rowSums),1,sd)
termite.S.sd.rand<-apply(apply(termite.plot.cor>0,3,rowSums),1,sd)

## By feeding group

termite.plot.rand.soil<-termite.plot.rand[,isopteraTaxonID$FG1=="S"]
termite.plot.rand.wood<-termite.plot.rand[,isopteraTaxonID$FG1=="W"]

termite.plot.PA.rand.soil<-termite.plot.PA.rand[,isopteraTaxonID$FG1=="S"]
termite.plot.PA.rand.wood<-termite.plot.PA.rand[,isopteraTaxonID$FG1=="W"]

termite.N.rand.wood<-rowMeans(apply(termite.plot.cor[,isopteraTaxonID$FG1=="W",],3,rowSums))
termite.N.rand.soil<-rowMeans(apply(termite.plot.cor[,isopteraTaxonID$FG1=="S",],3,rowSums))

termite.N.rand.wood[is.na(termite.N.rand)]<-NA
termite.N.rand.soil[is.na(termite.N.rand)]<-NA

termite.S.rand.wood<-rowMeans(apply(termite.plot.cor[,isopteraTaxonID$FG1=="W",]>0,3,rowSums))
termite.S.rand.soil<-rowMeans(apply(termite.plot.cor[,isopteraTaxonID$FG1=="S",]>0,3,rowSums))

termite.S.rand.wood[is.na(termite.N.rand)]<-NA
termite.S.rand.soil[is.na(termite.N.rand)]<-NA


#################### Compare randomization with exact results

plot(termite.plot,termite.plot.rand)
abline(0,1)

plot(termite.plot.wood,termite.plot.rand.wood)
abline(0,1)

plot(termite.plot.soil,termite.plot.rand.soil)
abline(0,1)

##

plot(termite.plot.PA,termite.plot.PA.rand)
abline(0,1)


plot(termite.plot.PA.wood,termite.plot.PA.rand.wood)
abline(0,1)

plot(termite.plot.PA.soil,termite.plot.PA.rand.soil)
abline(0,1)

##

plot(termite.N,termite.N.rand)
abline(0,1)

plot(termite.N.wood,termite.N.rand.wood)
abline(0,1)

plot(termite.N.soil,termite.N.rand.soil)
abline(0,1)

##

plot(termite.S,termite.S.rand)
abline(0,1)

plot(termite.S.wood,termite.S.rand.wood)
abline(0,1)

plot(termite.S.soil,termite.S.rand.soil)
abline(0,1)
